import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import { StreamingBlobTypes } from "@smithy/types";
import { SageMakerGeospatialServiceException as __BaseException } from "./SageMakerGeospatialServiceException";
/**
 * @public
 * <p>You do not have sufficient access to perform this action.</p>
 */
export declare class AccessDeniedException extends __BaseException {
    readonly name: "AccessDeniedException";
    readonly $fault: "client";
    Message: string | undefined;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<AccessDeniedException, __BaseException>);
}
/**
 * @public
 * @enum
 */
export declare const AlgorithmNameCloudRemoval: {
    /**
     * INTERPOLATION
     */
    readonly INTERPOLATION: "INTERPOLATION";
};
/**
 * @public
 */
export type AlgorithmNameCloudRemoval = (typeof AlgorithmNameCloudRemoval)[keyof typeof AlgorithmNameCloudRemoval];
/**
 * @public
 * @enum
 */
export declare const AlgorithmNameGeoMosaic: {
    /**
     * AVERAGE
     */
    readonly AVERAGE: "AVERAGE";
    /**
     * BILINEAR
     */
    readonly BILINEAR: "BILINEAR";
    /**
     * CUBIC
     */
    readonly CUBIC: "CUBIC";
    /**
     * CUBICSPLINE
     */
    readonly CUBICSPLINE: "CUBICSPLINE";
    /**
     * LANCZOS
     */
    readonly LANCZOS: "LANCZOS";
    /**
     * MAX
     */
    readonly MAX: "MAX";
    /**
     * MED
     */
    readonly MED: "MED";
    /**
     * MIN
     */
    readonly MIN: "MIN";
    /**
     * MODE
     */
    readonly MODE: "MODE";
    /**
     * NEAR
     */
    readonly NEAR: "NEAR";
    /**
     * Q1
     */
    readonly Q1: "Q1";
    /**
     * Q3
     */
    readonly Q3: "Q3";
    /**
     * RMS
     */
    readonly RMS: "RMS";
    /**
     * SUM
     */
    readonly SUM: "SUM";
};
/**
 * @public
 */
export type AlgorithmNameGeoMosaic = (typeof AlgorithmNameGeoMosaic)[keyof typeof AlgorithmNameGeoMosaic];
/**
 * @public
 * @enum
 */
export declare const AlgorithmNameResampling: {
    /**
     * AVERAGE
     */
    readonly AVERAGE: "AVERAGE";
    /**
     * BILINEAR
     */
    readonly BILINEAR: "BILINEAR";
    /**
     * CUBIC
     */
    readonly CUBIC: "CUBIC";
    /**
     * CUBICSPLINE
     */
    readonly CUBICSPLINE: "CUBICSPLINE";
    /**
     * LANCZOS
     */
    readonly LANCZOS: "LANCZOS";
    /**
     * MAX
     */
    readonly MAX: "MAX";
    /**
     * MED
     */
    readonly MED: "MED";
    /**
     * MIN
     */
    readonly MIN: "MIN";
    /**
     * MODE
     */
    readonly MODE: "MODE";
    /**
     * NEAR
     */
    readonly NEAR: "NEAR";
    /**
     * Q1
     */
    readonly Q1: "Q1";
    /**
     * Q3
     */
    readonly Q3: "Q3";
    /**
     * RMS
     */
    readonly RMS: "RMS";
    /**
     * SUM
     */
    readonly SUM: "SUM";
};
/**
 * @public
 */
export type AlgorithmNameResampling = (typeof AlgorithmNameResampling)[keyof typeof AlgorithmNameResampling];
/**
 * @public
 * <p>The structure representing Polygon Geometry based on the <a href="https://www.rfc-editor.org/rfc/rfc7946#section-3.1.6">GeoJson spec</a>.</p>
 */
export interface MultiPolygonGeometryInput {
    /**
     * @public
     * <p>The coordinates of the multipolygon geometry.</p>
     */
    Coordinates: number[][][][] | undefined;
}
/**
 * @public
 * <p>The structure representing Polygon Geometry based on the <a href="https://www.rfc-editor.org/rfc/rfc7946#section-3.1.6">GeoJson spec</a>.</p>
 */
export interface PolygonGeometryInput {
    /**
     * @public
     * <p>Coordinates representing a Polygon based on the <a href="https://www.rfc-editor.org/rfc/rfc7946#section-3.1.6">GeoJson spec</a>.</p>
     */
    Coordinates: number[][][] | undefined;
}
/**
 * @public
 * <p>A GeoJSON object representing the geographic extent in the coordinate space.</p>
 */
export type AreaOfInterestGeometry = AreaOfInterestGeometry.MultiPolygonGeometryMember | AreaOfInterestGeometry.PolygonGeometryMember | AreaOfInterestGeometry.$UnknownMember;
/**
 * @public
 */
export declare namespace AreaOfInterestGeometry {
    /**
     * @public
     * <p>The structure representing Polygon Geometry.</p>
     */
    interface PolygonGeometryMember {
        PolygonGeometry: PolygonGeometryInput;
        MultiPolygonGeometry?: never;
        $unknown?: never;
    }
    /**
     * @public
     * <p>The structure representing the MultiPolygon Geometry.</p>
     */
    interface MultiPolygonGeometryMember {
        PolygonGeometry?: never;
        MultiPolygonGeometry: MultiPolygonGeometryInput;
        $unknown?: never;
    }
    /**
     * @public
     */
    interface $UnknownMember {
        PolygonGeometry?: never;
        MultiPolygonGeometry?: never;
        $unknown: [string, any];
    }
    interface Visitor<T> {
        PolygonGeometry: (value: PolygonGeometryInput) => T;
        MultiPolygonGeometry: (value: MultiPolygonGeometryInput) => T;
        _: (name: string, value: any) => T;
    }
    const visit: <T>(value: AreaOfInterestGeometry, visitor: Visitor<T>) => T;
}
/**
 * @public
 * <p>The geographic extent of the Earth Observation job.</p>
 */
export type AreaOfInterest = AreaOfInterest.AreaOfInterestGeometryMember | AreaOfInterest.$UnknownMember;
/**
 * @public
 */
export declare namespace AreaOfInterest {
    /**
     * @public
     * <p>A GeoJSON object representing the geographic extent in the coordinate space.</p>
     */
    interface AreaOfInterestGeometryMember {
        AreaOfInterestGeometry: AreaOfInterestGeometry;
        $unknown?: never;
    }
    /**
     * @public
     */
    interface $UnknownMember {
        AreaOfInterestGeometry?: never;
        $unknown: [string, any];
    }
    interface Visitor<T> {
        AreaOfInterestGeometry: (value: AreaOfInterestGeometry) => T;
        _: (name: string, value: any) => T;
    }
    const visit: <T>(value: AreaOfInterest, visitor: Visitor<T>) => T;
}
/**
 * @public
 * <p>The structure containing the asset properties.</p>
 */
export interface AssetValue {
    /**
     * @public
     * <p>Link to the asset object.</p>
     */
    Href?: string;
}
/**
 * @public
 * @enum
 */
export declare const OutputType: {
    /**
     * FLOAT32
     */
    readonly FLOAT32: "FLOAT32";
    /**
     * FLOAT64
     */
    readonly FLOAT64: "FLOAT64";
    /**
     * INT16
     */
    readonly INT16: "INT16";
    /**
     * INT32
     */
    readonly INT32: "INT32";
    /**
     * UINT16
     */
    readonly UINT16: "UINT16";
};
/**
 * @public
 */
export type OutputType = (typeof OutputType)[keyof typeof OutputType];
/**
 * @public
 * <p>Represents an arithmetic operation to compute spectral index.</p>
 */
export interface Operation {
    /**
     * @public
     * <p>The name of the operation.</p>
     */
    Name: string | undefined;
    /**
     * @public
     * <p>Textual representation of the math operation; Equation used to compute the spectral index.</p>
     */
    Equation: string | undefined;
    /**
     * @public
     * <p>The type of the operation.</p>
     */
    OutputType?: OutputType;
}
/**
 * @public
 * <p>Input object defining the custom BandMath indices to compute.</p>
 */
export interface CustomIndicesInput {
    /**
     * @public
     * <p>A list of BandMath indices to compute.</p>
     */
    Operations?: Operation[];
}
/**
 * @public
 * <p>Input structure for the BandMath operation type.
 *       Defines Predefined and CustomIndices to be computed using BandMath.</p>
 */
export interface BandMathConfigInput {
    /**
     * @public
     * <p>One or many of the supported predefined indices to compute.
     *       Allowed values: <code>NDVI</code>, <code>EVI2</code>, <code>MSAVI</code>,
     *       <code>NDWI</code>, <code>NDMI</code>, <code>NDSI</code>, and <code>WDRVI</code>.</p>
     */
    PredefinedIndices?: string[];
    /**
     * @public
     * <p>CustomIndices that are computed.</p>
     */
    CustomIndices?: CustomIndicesInput;
}
/**
 * @public
 * <p>Input structure for CloudMasking operation type.</p>
 */
export interface CloudMaskingConfigInput {
}
/**
 * @public
 * <p>Input structure for Cloud Removal Operation type</p>
 */
export interface CloudRemovalConfigInput {
    /**
     * @public
     * <p>The name of the algorithm used for cloud removal.</p>
     */
    AlgorithmName?: AlgorithmNameCloudRemoval;
    /**
     * @public
     * <p>The interpolation value you provide for cloud removal.</p>
     */
    InterpolationValue?: string;
    /**
     * @public
     * <p>TargetBands to be returned in the output of CloudRemoval operation.</p>
     */
    TargetBands?: string[];
}
/**
 * @public
 * @enum
 */
export declare const ComparisonOperator: {
    /**
     * EQUALS
     */
    readonly EQUALS: "EQUALS";
    /**
     * NOT_EQUALS
     */
    readonly NOT_EQUALS: "NOT_EQUALS";
    /**
     * STARTS_WITH
     */
    readonly STARTS_WITH: "STARTS_WITH";
};
/**
 * @public
 */
export type ComparisonOperator = (typeof ComparisonOperator)[keyof typeof ComparisonOperator];
/**
 * @public
 * <p>Updating or deleting a resource can cause an inconsistent state.</p>
 */
export declare class ConflictException extends __BaseException {
    readonly name: "ConflictException";
    readonly $fault: "client";
    Message: string | undefined;
    /**
     * @public
     * <p>Identifier of the resource affected.</p>
     */
    ResourceId?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}
/**
 * @public
 * <p>The structure representing the filters supported by a RasterDataCollection.</p>
 */
export interface Filter {
    /**
     * @public
     * <p>The name of the filter.</p>
     */
    Name: string | undefined;
    /**
     * @public
     * <p>The type of the filter being used.</p>
     */
    Type: string | undefined;
    /**
     * @public
     * <p>The minimum value of the filter.</p>
     */
    Minimum?: number;
    /**
     * @public
     * <p>The maximum value of the filter.</p>
     */
    Maximum?: number;
}
/**
 * @public
 * @enum
 */
export declare const DataCollectionType: {
    /**
     * PREMIUM
     */
    readonly PREMIUM: "PREMIUM";
    /**
     * PUBLIC
     */
    readonly PUBLIC: "PUBLIC";
    /**
     * USER
     */
    readonly USER: "USER";
};
/**
 * @public
 */
export type DataCollectionType = (typeof DataCollectionType)[keyof typeof DataCollectionType];
/**
 * @public
 * <p>Response object containing details for a specific RasterDataCollection.</p>
 */
export interface RasterDataCollectionMetadata {
    /**
     * @public
     * <p>The name of the raster data collection.</p>
     */
    Name: string | undefined;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the raster data collection.</p>
     */
    Arn: string | undefined;
    /**
     * @public
     * <p>The type of raster data collection.</p>
     */
    Type: DataCollectionType | undefined;
    /**
     * @public
     * <p>A description of the raster data collection.</p>
     */
    Description: string | undefined;
    /**
     * @public
     * <p>The description URL of the raster data collection.</p>
     */
    DescriptionPageUrl?: string;
    /**
     * @public
     * <p>The list of filters supported by the raster data collection.</p>
     */
    SupportedFilters: Filter[] | undefined;
    /**
     * @public
     * <p>Each tag consists of a key and a value.</p>
     */
    Tags?: Record<string, string>;
}
/**
 * @public
 */
export interface DeleteEarthObservationJobInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the Earth Observation job being deleted.</p>
     */
    Arn: string | undefined;
}
/**
 * @public
 */
export interface DeleteEarthObservationJobOutput {
}
/**
 * @public
 * <p>The request processing has failed because of an unknown error, exception, or failure.</p>
 */
export declare class InternalServerException extends __BaseException {
    readonly name: "InternalServerException";
    readonly $fault: "server";
    Message: string | undefined;
    /**
     * @public
     * <p/>
     */
    ResourceId?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InternalServerException, __BaseException>);
}
/**
 * @public
 * <p>The request references a resource which does not exist.</p>
 */
export declare class ResourceNotFoundException extends __BaseException {
    readonly name: "ResourceNotFoundException";
    readonly $fault: "client";
    Message: string | undefined;
    /**
     * @public
     * <p>Identifier of the resource that was not found.</p>
     */
    ResourceId?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>);
}
/**
 * @public
 * <p>The request was denied due to request throttling.</p>
 */
export declare class ThrottlingException extends __BaseException {
    readonly name: "ThrottlingException";
    readonly $fault: "client";
    Message: string | undefined;
    /**
     * @public
     * <p/>
     */
    ResourceId?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ThrottlingException, __BaseException>);
}
/**
 * @public
 * <p>The input fails to satisfy the constraints specified by an Amazon Web Services service.</p>
 */
export declare class ValidationException extends __BaseException {
    readonly name: "ValidationException";
    readonly $fault: "client";
    Message: string | undefined;
    /**
     * @public
     * <p/>
     */
    ResourceId?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ValidationException, __BaseException>);
}
/**
 * @public
 */
export interface DeleteVectorEnrichmentJobInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the Vector Enrichment job being deleted.</p>
     */
    Arn: string | undefined;
}
/**
 * @public
 */
export interface DeleteVectorEnrichmentJobOutput {
}
/**
 * @public
 * <p>The structure containing the Amazon S3 path to export the Earth Observation job output.</p>
 */
export interface ExportS3DataInput {
    /**
     * @public
     * <p>The URL to the Amazon S3 data input.</p>
     */
    S3Uri: string | undefined;
    /**
     * @public
     * <p>The Key Management Service key ID for server-side encryption.</p>
     */
    KmsKeyId?: string;
}
/**
 * @public
 * <p>The response structure for an OutputConfig returned by an ExportEarthObservationJob.</p>
 */
export interface OutputConfigInput {
    /**
     * @public
     * <p>Path to Amazon S3 storage location for the output configuration file.</p>
     */
    S3Data: ExportS3DataInput | undefined;
}
/**
 * @public
 */
export interface ExportEarthObservationJobInput {
    /**
     * @public
     * <p>The input Amazon Resource Name (ARN) of the Earth Observation job being exported.</p>
     */
    Arn: string | undefined;
    /**
     * @public
     * <p>A unique token that guarantees that the call to this API is idempotent.</p>
     */
    ClientToken?: string;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the IAM role that you specified for the job.</p>
     */
    ExecutionRoleArn: string | undefined;
    /**
     * @public
     * <p>An object containing information about the output file.</p>
     */
    OutputConfig: OutputConfigInput | undefined;
    /**
     * @public
     * <p>The source images provided to the Earth Observation job being exported.</p>
     */
    ExportSourceImages?: boolean;
}
/**
 * @public
 * @enum
 */
export declare const EarthObservationJobExportStatus: {
    /**
     * FAILED
     */
    readonly FAILED: "FAILED";
    /**
     * IN_PROGRESS
     */
    readonly IN_PROGRESS: "IN_PROGRESS";
    /**
     * SUCCEEDED
     */
    readonly SUCCEEDED: "SUCCEEDED";
};
/**
 * @public
 */
export type EarthObservationJobExportStatus = (typeof EarthObservationJobExportStatus)[keyof typeof EarthObservationJobExportStatus];
/**
 * @public
 */
export interface ExportEarthObservationJobOutput {
    /**
     * @public
     * <p>The output Amazon Resource Name (ARN) of the Earth Observation job being exported.</p>
     */
    Arn: string | undefined;
    /**
     * @public
     * <p>The creation time.</p>
     */
    CreationTime: Date | undefined;
    /**
     * @public
     * <p>The status of the results of the Earth Observation job being exported.</p>
     */
    ExportStatus: EarthObservationJobExportStatus | undefined;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the IAM role that you specified for the job.</p>
     */
    ExecutionRoleArn: string | undefined;
    /**
     * @public
     * <p>An object containing information about the output file.</p>
     */
    OutputConfig: OutputConfigInput | undefined;
    /**
     * @public
     * <p>The source images provided to the Earth Observation job being exported.</p>
     */
    ExportSourceImages?: boolean;
}
/**
 * @public
 * <p>You have exceeded the service quota.</p>
 */
export declare class ServiceQuotaExceededException extends __BaseException {
    readonly name: "ServiceQuotaExceededException";
    readonly $fault: "client";
    Message: string | undefined;
    /**
     * @public
     * <p>Identifier of the resource affected.</p>
     */
    ResourceId?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ServiceQuotaExceededException, __BaseException>);
}
/**
 * @public
 */
export interface GetEarthObservationJobInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the Earth Observation job.</p>
     */
    Arn: string | undefined;
}
/**
 * @public
 * @enum
 */
export declare const EarthObservationJobErrorType: {
    /**
     * CLIENT_ERROR
     */
    readonly CLIENT_ERROR: "CLIENT_ERROR";
    /**
     * SERVER_ERROR
     */
    readonly SERVER_ERROR: "SERVER_ERROR";
};
/**
 * @public
 */
export type EarthObservationJobErrorType = (typeof EarthObservationJobErrorType)[keyof typeof EarthObservationJobErrorType];
/**
 * @public
 * <p>The structure representing the errors in an EarthObservationJob.</p>
 */
export interface EarthObservationJobErrorDetails {
    /**
     * @public
     * <p>The type of error in an Earth Observation job.</p>
     */
    Type?: EarthObservationJobErrorType;
    /**
     * @public
     * <p>A detailed message describing the error in an Earth Observation job.</p>
     */
    Message?: string;
}
/**
 * @public
 * @enum
 */
export declare const ExportErrorType: {
    /**
     * CLIENT_ERROR
     */
    readonly CLIENT_ERROR: "CLIENT_ERROR";
    /**
     * SERVER_ERROR
     */
    readonly SERVER_ERROR: "SERVER_ERROR";
};
/**
 * @public
 */
export type ExportErrorType = (typeof ExportErrorType)[keyof typeof ExportErrorType];
/**
 * @public
 * <p>The structure representing the errors in an export EarthObservationJob operation.</p>
 */
export interface ExportErrorDetailsOutput {
    /**
     * @public
     * <p>The type of error in an export EarthObservationJob operation.</p>
     */
    Type?: ExportErrorType;
    /**
     * @public
     * <p>A detailed message describing the error in an export EarthObservationJob operation.</p>
     */
    Message?: string;
}
/**
 * @public
 * <p>The structure for returning the export error details in a GetEarthObservationJob.</p>
 */
export interface ExportErrorDetails {
    /**
     * @public
     * <p>The structure for returning the export error details while exporting results of an Earth Observation job.</p>
     */
    ExportResults?: ExportErrorDetailsOutput;
    /**
     * @public
     * <p>The structure for returning the export error details
     *       while exporting the source images of an Earth Observation job.</p>
     */
    ExportSourceImages?: ExportErrorDetailsOutput;
}
/**
 * @public
 * @enum
 */
export declare const LogicalOperator: {
    /**
     * AND
     */
    readonly AND: "AND";
};
/**
 * @public
 */
export type LogicalOperator = (typeof LogicalOperator)[keyof typeof LogicalOperator];
/**
 * @public
 * <p>The structure representing the EoCloudCover filter.</p>
 */
export interface EoCloudCoverInput {
    /**
     * @public
     * <p>Lower bound for EoCloudCover.</p>
     */
    LowerBound: number | undefined;
    /**
     * @public
     * <p>Upper bound for EoCloudCover.</p>
     */
    UpperBound: number | undefined;
}
/**
 * @public
 * <p>The structure representing Land Cloud Cover property for Landsat data collection.</p>
 */
export interface LandsatCloudCoverLandInput {
    /**
     * @public
     * <p>The minimum value for Land Cloud Cover property filter. This will filter items
     *       having Land Cloud Cover greater than or equal to this value.</p>
     */
    LowerBound: number | undefined;
    /**
     * @public
     * <p>The maximum value for Land Cloud Cover property filter.
     *       This will filter items having Land Cloud Cover less than or equal to this value.</p>
     */
    UpperBound: number | undefined;
}
/**
 * @public
 * <p>The input structure for specifying Platform.
 *       Platform refers to the unique name of the specific platform the
 *       instrument is attached to. For satellites it is the name of the satellite, eg. landsat-8 (Landsat-8), sentinel-2a.</p>
 */
export interface PlatformInput {
    /**
     * @public
     * <p>The value of the platform.</p>
     */
    Value: string | undefined;
    /**
     * @public
     * <p>The ComparisonOperator to use with PlatformInput.</p>
     */
    ComparisonOperator?: ComparisonOperator;
}
/**
 * @public
 * <p>The input structure for specifying ViewOffNadir property filter.
 *       ViewOffNadir refers to the angle from the sensor between
 *       nadir (straight down) and the scene center. Measured in degrees (0-90).</p>
 */
export interface ViewOffNadirInput {
    /**
     * @public
     * <p>The minimum value for ViewOffNadir property filter.
     *       This filters items having ViewOffNadir greater than or equal to this value. </p>
     */
    LowerBound: number | undefined;
    /**
     * @public
     * <p>The maximum value for ViewOffNadir property filter.
     *       This filters items having ViewOffNadir lesser than or equal to this value.</p>
     */
    UpperBound: number | undefined;
}
/**
 * @public
 * <p>The input structure for specifying ViewSunAzimuth property filter.
 *       ViewSunAzimuth refers to the Sun azimuth angle.
 *       From the scene center point on the ground,
 *       this is the angle between truth north and the sun.
 *       Measured clockwise in degrees (0-360).</p>
 */
export interface ViewSunAzimuthInput {
    /**
     * @public
     * <p>The minimum value for ViewSunAzimuth property filter.
     *       This filters items having ViewSunAzimuth greater than or equal to this value.</p>
     */
    LowerBound: number | undefined;
    /**
     * @public
     * <p>The maximum value for ViewSunAzimuth property filter.
     *       This filters items having ViewSunAzimuth lesser than or equal to this value.</p>
     */
    UpperBound: number | undefined;
}
/**
 * @public
 * <p>The input structure for specifying ViewSunElevation angle property filter. </p>
 */
export interface ViewSunElevationInput {
    /**
     * @public
     * <p>The lower bound to view the sun elevation.</p>
     */
    LowerBound: number | undefined;
    /**
     * @public
     * <p>The upper bound to view the sun elevation.</p>
     */
    UpperBound: number | undefined;
}
/**
 * @public
 * <p>Represents a single searchable property to search on.</p>
 */
export type Property = Property.EoCloudCoverMember | Property.LandsatCloudCoverLandMember | Property.PlatformMember | Property.ViewOffNadirMember | Property.ViewSunAzimuthMember | Property.ViewSunElevationMember | Property.$UnknownMember;
/**
 * @public
 */
export declare namespace Property {
    /**
     * @public
     * <p>The structure representing EoCloudCover property filter containing a lower bound and upper bound.</p>
     */
    interface EoCloudCoverMember {
        EoCloudCover: EoCloudCoverInput;
        ViewOffNadir?: never;
        ViewSunAzimuth?: never;
        ViewSunElevation?: never;
        Platform?: never;
        LandsatCloudCoverLand?: never;
        $unknown?: never;
    }
    /**
     * @public
     * <p>The structure representing ViewOffNadir property filter containing a lower bound and upper bound.</p>
     */
    interface ViewOffNadirMember {
        EoCloudCover?: never;
        ViewOffNadir: ViewOffNadirInput;
        ViewSunAzimuth?: never;
        ViewSunElevation?: never;
        Platform?: never;
        LandsatCloudCoverLand?: never;
        $unknown?: never;
    }
    /**
     * @public
     * <p>The structure representing ViewSunAzimuth property filter containing a lower bound and upper bound.</p>
     */
    interface ViewSunAzimuthMember {
        EoCloudCover?: never;
        ViewOffNadir?: never;
        ViewSunAzimuth: ViewSunAzimuthInput;
        ViewSunElevation?: never;
        Platform?: never;
        LandsatCloudCoverLand?: never;
        $unknown?: never;
    }
    /**
     * @public
     * <p>The structure representing ViewSunElevation property filter containing a lower bound and upper bound.</p>
     */
    interface ViewSunElevationMember {
        EoCloudCover?: never;
        ViewOffNadir?: never;
        ViewSunAzimuth?: never;
        ViewSunElevation: ViewSunElevationInput;
        Platform?: never;
        LandsatCloudCoverLand?: never;
        $unknown?: never;
    }
    /**
     * @public
     * <p>The structure representing Platform property filter consisting of value and comparison operator.</p>
     */
    interface PlatformMember {
        EoCloudCover?: never;
        ViewOffNadir?: never;
        ViewSunAzimuth?: never;
        ViewSunElevation?: never;
        Platform: PlatformInput;
        LandsatCloudCoverLand?: never;
        $unknown?: never;
    }
    /**
     * @public
     * <p>The structure representing Land Cloud Cover property filter
     *       for Landsat collection containing a lower bound and upper bound.</p>
     */
    interface LandsatCloudCoverLandMember {
        EoCloudCover?: never;
        ViewOffNadir?: never;
        ViewSunAzimuth?: never;
        ViewSunElevation?: never;
        Platform?: never;
        LandsatCloudCoverLand: LandsatCloudCoverLandInput;
        $unknown?: never;
    }
    /**
     * @public
     */
    interface $UnknownMember {
        EoCloudCover?: never;
        ViewOffNadir?: never;
        ViewSunAzimuth?: never;
        ViewSunElevation?: never;
        Platform?: never;
        LandsatCloudCoverLand?: never;
        $unknown: [string, any];
    }
    interface Visitor<T> {
        EoCloudCover: (value: EoCloudCoverInput) => T;
        ViewOffNadir: (value: ViewOffNadirInput) => T;
        ViewSunAzimuth: (value: ViewSunAzimuthInput) => T;
        ViewSunElevation: (value: ViewSunElevationInput) => T;
        Platform: (value: PlatformInput) => T;
        LandsatCloudCoverLand: (value: LandsatCloudCoverLandInput) => T;
        _: (name: string, value: any) => T;
    }
    const visit: <T>(value: Property, visitor: Visitor<T>) => T;
}
/**
 * @public
 * <p>The structure representing a single PropertyFilter.</p>
 */
export interface PropertyFilter {
    /**
     * @public
     * <p>Represents a single property to match with when searching a raster data collection.</p>
     */
    Property: Property | undefined;
}
/**
 * @public
 * <p>A list of PropertyFilter objects.</p>
 */
export interface PropertyFilters {
    /**
     * @public
     * <p>A list of Property Filters.</p>
     */
    Properties?: PropertyFilter[];
    /**
     * @public
     * <p>The Logical Operator used to combine the Property Filters.</p>
     */
    LogicalOperator?: LogicalOperator;
}
/**
 * @public
 * <p>The output structure of the time range filter.</p>
 */
export interface TimeRangeFilterOutput {
    /**
     * @public
     * <p>The starting time for the time range filter.</p>
     */
    StartTime: Date | undefined;
    /**
     * @public
     * <p>The ending time for the time range filter.</p>
     */
    EndTime: Date | undefined;
}
/**
 * @public
 * <p>The output structure contains the Raster Data Collection Query
 *       input along with some additional metadata.</p>
 */
export interface RasterDataCollectionQueryOutput {
    /**
     * @public
     * <p>The ARN of the Raster Data Collection against which the search is done.</p>
     */
    RasterDataCollectionArn: string | undefined;
    /**
     * @public
     * <p>The name of the raster data collection.</p>
     */
    RasterDataCollectionName: string | undefined;
    /**
     * @public
     * <p>The TimeRange filter used in the search.</p>
     */
    TimeRangeFilter: TimeRangeFilterOutput | undefined;
    /**
     * @public
     * <p>The Area of Interest used in the search.</p>
     */
    AreaOfInterest?: AreaOfInterest;
    /**
     * @public
     * <p>Property filters used in the search.</p>
     */
    PropertyFilters?: PropertyFilters;
}
/**
 * @public
 * <p>The InputConfig for an EarthObservationJob response.</p>
 */
export interface InputConfigOutput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the previous Earth Observation job.</p>
     */
    PreviousEarthObservationJobArn?: string;
    /**
     * @public
     * <p>The structure representing the RasterDataCollection Query consisting of the Area of Interest,
     *       RasterDataCollectionArn, RasterDataCollectionName, TimeRange, and Property Filters.</p>
     */
    RasterDataCollectionQuery?: RasterDataCollectionQueryOutput;
}
/**
 * @public
 * <p>Input configuration information for the geomosaic.</p>
 */
export interface GeoMosaicConfigInput {
    /**
     * @public
     * <p>The name of the algorithm being used for geomosaic.</p>
     */
    AlgorithmName?: AlgorithmNameGeoMosaic;
    /**
     * @public
     * <p>The target bands for geomosaic.</p>
     */
    TargetBands?: string[];
}
/**
 * @public
 * <p>The input structure for Land Cover Operation type.</p>
 */
export interface LandCoverSegmentationConfigInput {
}
/**
 * @public
 * @enum
 */
export declare const Unit: {
    /**
     * METERS
     */
    readonly METERS: "METERS";
};
/**
 * @public
 */
export type Unit = (typeof Unit)[keyof typeof Unit];
/**
 * @public
 * <p>The output resolution (in target georeferenced units)
 *       of the result of the operation</p>
 */
export interface UserDefined {
    /**
     * @public
     * <p>The value for output resolution of the result.</p>
     */
    Value: number | undefined;
    /**
     * @public
     * <p>The units for output resolution of the result.</p>
     */
    Unit: Unit | undefined;
}
/**
 * @public
 * <p>OutputResolution Configuration indicating
 *       the target resolution for the output of Resampling operation.</p>
 */
export interface OutputResolutionResamplingInput {
    /**
     * @public
     * <p>User Defined Resolution for the output
     *       of Resampling operation defined by value and unit.</p>
     */
    UserDefined: UserDefined | undefined;
}
/**
 * @public
 * <p>The structure representing input for resampling operation.</p>
 */
export interface ResamplingConfigInput {
    /**
     * @public
     * <p>The structure representing output
     *       resolution (in target georeferenced units) of the result of resampling operation.</p>
     */
    OutputResolution: OutputResolutionResamplingInput | undefined;
    /**
     * @public
     * <p>The name of the algorithm used for resampling.</p>
     */
    AlgorithmName?: AlgorithmNameResampling;
    /**
     * @public
     * <p>Bands used in the operation. If no target bands are specified, it uses all bands available in the input.</p>
     */
    TargetBands?: string[];
}
/**
 * @public
 * @enum
 */
export declare const PredefinedResolution: {
    /**
     * AVERAGE
     */
    readonly AVERAGE: "AVERAGE";
    /**
     * HIGHEST
     */
    readonly HIGHEST: "HIGHEST";
    /**
     * LOWEST
     */
    readonly LOWEST: "LOWEST";
};
/**
 * @public
 */
export type PredefinedResolution = (typeof PredefinedResolution)[keyof typeof PredefinedResolution];
/**
 * @public
 * <p>The input structure representing Output Resolution for Stacking Operation.</p>
 */
export interface OutputResolutionStackInput {
    /**
     * @public
     * <p>A string value representing Predefined Output Resolution for a stacking operation. Allowed values are <code>HIGHEST</code>, <code>LOWEST</code>, and <code>AVERAGE</code>.</p>
     */
    Predefined?: PredefinedResolution;
    /**
     * @public
     * <p>The structure representing User Output Resolution for a Stacking operation defined as a value and unit.</p>
     */
    UserDefined?: UserDefined;
}
/**
 * @public
 * <p>The input structure for Stacking Operation.</p>
 */
export interface StackConfigInput {
    /**
     * @public
     * <p>The structure representing output
     *       resolution (in target georeferenced units) of the
     *       result of stacking operation.</p>
     */
    OutputResolution?: OutputResolutionStackInput;
    /**
     * @public
     * <p>A list of bands to be stacked in the specified order. When the parameter is not provided, all the available bands in the data collection are stacked in the alphabetical order of their asset names.</p>
     */
    TargetBands?: string[];
}
/**
 * @public
 * @enum
 */
export declare const GroupBy: {
    /**
     * ALL
     */
    readonly ALL: "ALL";
    /**
     * YEARLY
     */
    readonly YEARLY: "YEARLY";
};
/**
 * @public
 */
export type GroupBy = (typeof GroupBy)[keyof typeof GroupBy];
/**
 * @public
 * @enum
 */
export declare const TemporalStatistics: {
    /**
     * MEAN
     */
    readonly MEAN: "MEAN";
    /**
     * MEDIAN
     */
    readonly MEDIAN: "MEDIAN";
    /**
     * STANDARD_DEVIATION
     */
    readonly STANDARD_DEVIATION: "STANDARD_DEVIATION";
};
/**
 * @public
 */
export type TemporalStatistics = (typeof TemporalStatistics)[keyof typeof TemporalStatistics];
/**
 * @public
 * <p>The structure representing the configuration for Temporal Statistics operation.</p>
 */
export interface TemporalStatisticsConfigInput {
    /**
     * @public
     * <p>The input for the temporal statistics grouping by time frequency option.</p>
     */
    GroupBy?: GroupBy;
    /**
     * @public
     * <p>The list of the statistics method options.</p>
     */
    Statistics: TemporalStatistics[] | undefined;
    /**
     * @public
     * <p>The list of target band names for the temporal statistic to calculate.</p>
     */
    TargetBands?: string[];
}
/**
 * @public
 * @enum
 */
export declare const ZonalStatistics: {
    /**
     * MAX
     */
    readonly MAX: "MAX";
    /**
     * MEAN
     */
    readonly MEAN: "MEAN";
    /**
     * MEDIAN
     */
    readonly MEDIAN: "MEDIAN";
    /**
     * MIN
     */
    readonly MIN: "MIN";
    /**
     * STANDARD_DEVIATION
     */
    readonly STANDARD_DEVIATION: "STANDARD_DEVIATION";
    /**
     * SUM
     */
    readonly SUM: "SUM";
};
/**
 * @public
 */
export type ZonalStatistics = (typeof ZonalStatistics)[keyof typeof ZonalStatistics];
/**
 * @public
 * <p>The structure representing input configuration of ZonalStatistics operation.</p>
 */
export interface ZonalStatisticsConfigInput {
    /**
     * @public
     * <p>The Amazon S3 path pointing to the GeoJSON containing the polygonal zones.</p>
     */
    ZoneS3Path: string | undefined;
    /**
     * @public
     * <p>List of zonal statistics to compute.</p>
     */
    Statistics: ZonalStatistics[] | undefined;
    /**
     * @public
     * <p>Bands used in the operation.
     *       If no target bands are specified, it uses all bands available input.</p>
     */
    TargetBands?: string[];
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) or an ID of a Amazon Web Services Key Management Service (Amazon Web Services KMS) key that Amazon SageMaker uses to decrypt your output artifacts with Amazon S3 server-side encryption.
     * The SageMaker execution role must have <code>kms:GenerateDataKey</code> permission.</p>
     *          <p>The <code>KmsKeyId</code> can be any of the following formats:</p>
     *          <ul>
     *             <li>
     *                <p>// KMS Key ID</p>
     *                <p>
     *                   <code>"1234abcd-12ab-34cd-56ef-1234567890ab"</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>// Amazon Resource Name (ARN) of a KMS Key</p>
     *                <p>
     *                   <code>"arn:aws:kms:&lt;region&gt;:&lt;account&gt;:key/&lt;key-id-12ab-34cd-56ef-1234567890ab&gt;"</code>
     *                </p>
     *             </li>
     *          </ul>
     *          <p>For more information about key identifiers, see
     * <a href="https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#key-id-key-id">Key identifiers (KeyID)</a> in the
     * Amazon Web Services Key Management Service (Amazon Web Services KMS) documentation.</p>
     */
    ZoneS3PathKmsKeyId?: string;
}
/**
 * @public
 * <p>The input structure for the JobConfig in an EarthObservationJob.</p>
 */
export type JobConfigInput = JobConfigInput.BandMathConfigMember | JobConfigInput.CloudMaskingConfigMember | JobConfigInput.CloudRemovalConfigMember | JobConfigInput.GeoMosaicConfigMember | JobConfigInput.LandCoverSegmentationConfigMember | JobConfigInput.ResamplingConfigMember | JobConfigInput.StackConfigMember | JobConfigInput.TemporalStatisticsConfigMember | JobConfigInput.ZonalStatisticsConfigMember | JobConfigInput.$UnknownMember;
/**
 * @public
 */
export declare namespace JobConfigInput {
    /**
     * @public
     * <p>An object containing information about the job configuration for BandMath.</p>
     */
    interface BandMathConfigMember {
        BandMathConfig: BandMathConfigInput;
        ResamplingConfig?: never;
        TemporalStatisticsConfig?: never;
        CloudRemovalConfig?: never;
        ZonalStatisticsConfig?: never;
        GeoMosaicConfig?: never;
        StackConfig?: never;
        CloudMaskingConfig?: never;
        LandCoverSegmentationConfig?: never;
        $unknown?: never;
    }
    /**
     * @public
     * <p>An object containing information about the job configuration for resampling.</p>
     */
    interface ResamplingConfigMember {
        BandMathConfig?: never;
        ResamplingConfig: ResamplingConfigInput;
        TemporalStatisticsConfig?: never;
        CloudRemovalConfig?: never;
        ZonalStatisticsConfig?: never;
        GeoMosaicConfig?: never;
        StackConfig?: never;
        CloudMaskingConfig?: never;
        LandCoverSegmentationConfig?: never;
        $unknown?: never;
    }
    /**
     * @public
     * <p>An object containing information about the job configuration for temporal statistics.</p>
     */
    interface TemporalStatisticsConfigMember {
        BandMathConfig?: never;
        ResamplingConfig?: never;
        TemporalStatisticsConfig: TemporalStatisticsConfigInput;
        CloudRemovalConfig?: never;
        ZonalStatisticsConfig?: never;
        GeoMosaicConfig?: never;
        StackConfig?: never;
        CloudMaskingConfig?: never;
        LandCoverSegmentationConfig?: never;
        $unknown?: never;
    }
    /**
     * @public
     * <p>An object containing information about the job configuration for cloud removal.</p>
     */
    interface CloudRemovalConfigMember {
        BandMathConfig?: never;
        ResamplingConfig?: never;
        TemporalStatisticsConfig?: never;
        CloudRemovalConfig: CloudRemovalConfigInput;
        ZonalStatisticsConfig?: never;
        GeoMosaicConfig?: never;
        StackConfig?: never;
        CloudMaskingConfig?: never;
        LandCoverSegmentationConfig?: never;
        $unknown?: never;
    }
    /**
     * @public
     * <p>An object containing information about the job configuration for zonal statistics.</p>
     */
    interface ZonalStatisticsConfigMember {
        BandMathConfig?: never;
        ResamplingConfig?: never;
        TemporalStatisticsConfig?: never;
        CloudRemovalConfig?: never;
        ZonalStatisticsConfig: ZonalStatisticsConfigInput;
        GeoMosaicConfig?: never;
        StackConfig?: never;
        CloudMaskingConfig?: never;
        LandCoverSegmentationConfig?: never;
        $unknown?: never;
    }
    /**
     * @public
     * <p>An object containing information about the job configuration for geomosaic.</p>
     */
    interface GeoMosaicConfigMember {
        BandMathConfig?: never;
        ResamplingConfig?: never;
        TemporalStatisticsConfig?: never;
        CloudRemovalConfig?: never;
        ZonalStatisticsConfig?: never;
        GeoMosaicConfig: GeoMosaicConfigInput;
        StackConfig?: never;
        CloudMaskingConfig?: never;
        LandCoverSegmentationConfig?: never;
        $unknown?: never;
    }
    /**
     * @public
     * <p>An object containing information about the job configuration for a Stacking Earth Observation job.</p>
     */
    interface StackConfigMember {
        BandMathConfig?: never;
        ResamplingConfig?: never;
        TemporalStatisticsConfig?: never;
        CloudRemovalConfig?: never;
        ZonalStatisticsConfig?: never;
        GeoMosaicConfig?: never;
        StackConfig: StackConfigInput;
        CloudMaskingConfig?: never;
        LandCoverSegmentationConfig?: never;
        $unknown?: never;
    }
    /**
     * @public
     * <p>An object containing information about the job configuration for cloud masking.</p>
     */
    interface CloudMaskingConfigMember {
        BandMathConfig?: never;
        ResamplingConfig?: never;
        TemporalStatisticsConfig?: never;
        CloudRemovalConfig?: never;
        ZonalStatisticsConfig?: never;
        GeoMosaicConfig?: never;
        StackConfig?: never;
        CloudMaskingConfig: CloudMaskingConfigInput;
        LandCoverSegmentationConfig?: never;
        $unknown?: never;
    }
    /**
     * @public
     * <p>An object containing information about the job configuration for land cover segmentation.</p>
     */
    interface LandCoverSegmentationConfigMember {
        BandMathConfig?: never;
        ResamplingConfig?: never;
        TemporalStatisticsConfig?: never;
        CloudRemovalConfig?: never;
        ZonalStatisticsConfig?: never;
        GeoMosaicConfig?: never;
        StackConfig?: never;
        CloudMaskingConfig?: never;
        LandCoverSegmentationConfig: LandCoverSegmentationConfigInput;
        $unknown?: never;
    }
    /**
     * @public
     */
    interface $UnknownMember {
        BandMathConfig?: never;
        ResamplingConfig?: never;
        TemporalStatisticsConfig?: never;
        CloudRemovalConfig?: never;
        ZonalStatisticsConfig?: never;
        GeoMosaicConfig?: never;
        StackConfig?: never;
        CloudMaskingConfig?: never;
        LandCoverSegmentationConfig?: never;
        $unknown: [string, any];
    }
    interface Visitor<T> {
        BandMathConfig: (value: BandMathConfigInput) => T;
        ResamplingConfig: (value: ResamplingConfigInput) => T;
        TemporalStatisticsConfig: (value: TemporalStatisticsConfigInput) => T;
        CloudRemovalConfig: (value: CloudRemovalConfigInput) => T;
        ZonalStatisticsConfig: (value: ZonalStatisticsConfigInput) => T;
        GeoMosaicConfig: (value: GeoMosaicConfigInput) => T;
        StackConfig: (value: StackConfigInput) => T;
        CloudMaskingConfig: (value: CloudMaskingConfigInput) => T;
        LandCoverSegmentationConfig: (value: LandCoverSegmentationConfigInput) => T;
        _: (name: string, value: any) => T;
    }
    const visit: <T>(value: JobConfigInput, visitor: Visitor<T>) => T;
}
/**
 * @public
 * <p>A single EarthObservationJob output band.</p>
 */
export interface OutputBand {
    /**
     * @public
     * <p>The name of the band.</p>
     */
    BandName: string | undefined;
    /**
     * @public
     * <p>The datatype of the output band.</p>
     */
    OutputDataType: OutputType | undefined;
}
/**
 * @public
 * @enum
 */
export declare const EarthObservationJobStatus: {
    /**
     * COMPLETED
     */
    readonly COMPLETED: "COMPLETED";
    /**
     * DELETED
     */
    readonly DELETED: "DELETED";
    /**
     * DELETING
     */
    readonly DELETING: "DELETING";
    /**
     * FAILED
     */
    readonly FAILED: "FAILED";
    /**
     * INITIALIZING
     */
    readonly INITIALIZING: "INITIALIZING";
    /**
     * IN_PROGRESS
     */
    readonly IN_PROGRESS: "IN_PROGRESS";
    /**
     * STOPPED
     */
    readonly STOPPED: "STOPPED";
    /**
     * STOPPING
     */
    readonly STOPPING: "STOPPING";
};
/**
 * @public
 */
export type EarthObservationJobStatus = (typeof EarthObservationJobStatus)[keyof typeof EarthObservationJobStatus];
/**
 * @public
 */
export interface GetEarthObservationJobOutput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the Earth Observation job.</p>
     */
    Arn: string | undefined;
    /**
     * @public
     * <p>The name of the Earth Observation job.</p>
     */
    Name: string | undefined;
    /**
     * @public
     * <p>The creation time of the initiated Earth Observation job.</p>
     */
    CreationTime: Date | undefined;
    /**
     * @public
     * <p>The duration of Earth Observation job, in seconds.</p>
     */
    DurationInSeconds: number | undefined;
    /**
     * @public
     * <p>The status of a previously initiated Earth Observation job.</p>
     */
    Status: EarthObservationJobStatus | undefined;
    /**
     * @public
     * <p>The Key Management Service key ID for server-side encryption.</p>
     */
    KmsKeyId?: string;
    /**
     * @public
     * <p>Input data for the Earth Observation job.</p>
     */
    InputConfig: InputConfigOutput | undefined;
    /**
     * @public
     * <p>An object containing information about the job configuration.</p>
     */
    JobConfig: JobConfigInput | undefined;
    /**
     * @public
     * <p>Bands available in the output of an operation.</p>
     */
    OutputBands?: OutputBand[];
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the IAM role that you specified for the job.</p>
     */
    ExecutionRoleArn?: string;
    /**
     * @public
     * <p>Details about the errors generated during the Earth Observation job.</p>
     */
    ErrorDetails?: EarthObservationJobErrorDetails;
    /**
     * @public
     * <p>The status of the Earth Observation job.</p>
     */
    ExportStatus?: EarthObservationJobExportStatus;
    /**
     * @public
     * <p>Details about the errors generated during ExportEarthObservationJob.</p>
     */
    ExportErrorDetails?: ExportErrorDetails;
    /**
     * @public
     * <p>Each tag consists of a key and a value.</p>
     */
    Tags?: Record<string, string>;
}
/**
 * @public
 * @enum
 */
export declare const TargetOptions: {
    /**
     * INPUT
     */
    readonly INPUT: "INPUT";
    /**
     * OUTPUT
     */
    readonly OUTPUT: "OUTPUT";
};
/**
 * @public
 */
export type TargetOptions = (typeof TargetOptions)[keyof typeof TargetOptions];
/**
 * @public
 */
export interface GetTileInput {
    /**
     * @public
     * <p>The x coordinate of the tile input.</p>
     */
    x: number | undefined;
    /**
     * @public
     * <p>The y coordinate of the tile input.</p>
     */
    y: number | undefined;
    /**
     * @public
     * <p>The z coordinate of the tile input.</p>
     */
    z: number | undefined;
    /**
     * @public
     * <p>The particular assets or bands to tile.</p>
     */
    ImageAssets: string[] | undefined;
    /**
     * @public
     * <p>Determines what part of the Earth Observation job to tile. 'INPUT' or 'OUTPUT' are the valid options.</p>
     */
    Target: TargetOptions | undefined;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the tile operation.</p>
     */
    Arn: string | undefined;
    /**
     * @public
     * <p>Determines whether or not to return a valid data mask.</p>
     */
    ImageMask?: boolean;
    /**
     * @public
     * <p>The data format of the output tile. The formats include .npy, .png and .jpg.</p>
     */
    OutputFormat?: string;
    /**
     * @public
     * <p>Time range filter applied to imagery to find the images to tile.</p>
     */
    TimeRangeFilter?: string;
    /**
     * @public
     * <p>Property filters for the imagery to tile.</p>
     */
    PropertyFilters?: string;
    /**
     * @public
     * <p>The output data type of the tile operation.</p>
     */
    OutputDataType?: OutputType;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the IAM role that you specify.</p>
     */
    ExecutionRoleArn?: string;
}
/**
 * @public
 */
export interface GetTileOutput {
    /**
     * @public
     * <p>The output binary file.</p>
     */
    BinaryFile?: StreamingBlobTypes;
}
/**
 * @public
 * @enum
 */
export declare const SortOrder: {
    /**
     * ASCENDING
     */
    readonly ASCENDING: "ASCENDING";
    /**
     * DESCENDING
     */
    readonly DESCENDING: "DESCENDING";
};
/**
 * @public
 */
export type SortOrder = (typeof SortOrder)[keyof typeof SortOrder];
/**
 * @public
 */
export interface ListEarthObservationJobInput {
    /**
     * @public
     * <p>A filter that retrieves only jobs with a specific status.</p>
     */
    StatusEquals?: EarthObservationJobStatus;
    /**
     * @public
     * <p>An optional value that specifies whether you want the results sorted in <code>Ascending</code> or <code>Descending</code> order.</p>
     */
    SortOrder?: SortOrder;
    /**
     * @public
     * <p>The parameter by which to sort the results.</p>
     */
    SortBy?: string;
    /**
     * @public
     * <p>If the previous response was truncated, you receive this token.
     *          Use it in your next request to receive the next set of results.</p>
     */
    NextToken?: string;
    /**
     * @public
     * <p>The total number of items to return.</p>
     */
    MaxResults?: number;
}
/**
 * @public
 * <p>An object containing information about the output file.</p>
 */
export interface ListEarthObservationJobOutputConfig {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the list of the Earth Observation jobs.</p>
     */
    Arn: string | undefined;
    /**
     * @public
     * <p>The names of the Earth Observation jobs in the list.</p>
     */
    Name: string | undefined;
    /**
     * @public
     * <p>The creation time.</p>
     */
    CreationTime: Date | undefined;
    /**
     * @public
     * <p>The duration of the session, in seconds.</p>
     */
    DurationInSeconds: number | undefined;
    /**
     * @public
     * <p>The status of the list of the Earth Observation jobs.</p>
     */
    Status: EarthObservationJobStatus | undefined;
    /**
     * @public
     * <p>The operation type for an Earth Observation job.</p>
     */
    OperationType: string | undefined;
    /**
     * @public
     * <p>Each tag consists of a key and a value.</p>
     */
    Tags?: Record<string, string>;
}
/**
 * @public
 */
export interface ListEarthObservationJobOutput {
    /**
     * @public
     * <p>Contains summary information about the Earth Observation jobs.</p>
     */
    EarthObservationJobSummaries: ListEarthObservationJobOutputConfig[] | undefined;
    /**
     * @public
     * <p>If the previous response was truncated, you receive this token.
     *          Use it in your next request to receive the next set of results.</p>
     */
    NextToken?: string;
}
/**
 * @public
 * <p>The input for the time-range filter.</p>
 */
export interface TimeRangeFilterInput {
    /**
     * @public
     * <p>The start time for the time-range filter.</p>
     */
    StartTime: Date | undefined;
    /**
     * @public
     * <p>The end time for the time-range filter.</p>
     */
    EndTime: Date | undefined;
}
/**
 * @public
 * <p>The input structure for Raster Data Collection Query containing the Area of Interest, TimeRange Filters, and Property Filters.</p>
 */
export interface RasterDataCollectionQueryInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the raster data collection.</p>
     */
    RasterDataCollectionArn: string | undefined;
    /**
     * @public
     * <p>The TimeRange Filter used in the RasterDataCollection Query.</p>
     */
    TimeRangeFilter: TimeRangeFilterInput | undefined;
    /**
     * @public
     * <p>The area of interest being queried for the raster data collection.</p>
     */
    AreaOfInterest?: AreaOfInterest;
    /**
     * @public
     * <p>The list of Property filters used in the Raster Data Collection Query.</p>
     */
    PropertyFilters?: PropertyFilters;
}
/**
 * @public
 * <p>Input configuration information.</p>
 */
export interface InputConfigInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the previous Earth Observation job.</p>
     */
    PreviousEarthObservationJobArn?: string;
    /**
     * @public
     * <p>The structure representing the RasterDataCollection Query consisting of
     *       the Area of Interest, RasterDataCollectionArn,TimeRange and Property Filters.</p>
     */
    RasterDataCollectionQuery?: RasterDataCollectionQueryInput;
}
/**
 * @public
 */
export interface StartEarthObservationJobInput {
    /**
     * @public
     * <p>The name of the Earth Observation job.</p>
     */
    Name: string | undefined;
    /**
     * @public
     * <p>A unique token that guarantees that the call to this API is idempotent.</p>
     */
    ClientToken?: string;
    /**
     * @public
     * <p>The Key Management Service key ID for server-side encryption.</p>
     */
    KmsKeyId?: string;
    /**
     * @public
     * <p>Input configuration information for the Earth Observation job.</p>
     */
    InputConfig: InputConfigInput | undefined;
    /**
     * @public
     * <p>An object containing information about the job configuration.</p>
     */
    JobConfig: JobConfigInput | undefined;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the IAM role that you specified for the job.</p>
     */
    ExecutionRoleArn: string | undefined;
    /**
     * @public
     * <p>Each tag consists of a key and a value.</p>
     */
    Tags?: Record<string, string>;
}
/**
 * @public
 */
export interface StartEarthObservationJobOutput {
    /**
     * @public
     * <p>The name of the Earth Observation job.</p>
     */
    Name: string | undefined;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the Earth Observation job.</p>
     */
    Arn: string | undefined;
    /**
     * @public
     * <p>The creation time.</p>
     */
    CreationTime: Date | undefined;
    /**
     * @public
     * <p>The duration of the session, in seconds.</p>
     */
    DurationInSeconds: number | undefined;
    /**
     * @public
     * <p>The status of the Earth Observation job.</p>
     */
    Status: EarthObservationJobStatus | undefined;
    /**
     * @public
     * <p>The Key Management Service key ID for server-side encryption.</p>
     */
    KmsKeyId?: string;
    /**
     * @public
     * <p>Input configuration information for the Earth Observation job.</p>
     */
    InputConfig?: InputConfigOutput;
    /**
     * @public
     * <p>An object containing information about the job configuration.</p>
     */
    JobConfig: JobConfigInput | undefined;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the IAM role that you specified for the job.</p>
     */
    ExecutionRoleArn: string | undefined;
    /**
     * @public
     * <p>Each tag consists of a key and a value.</p>
     */
    Tags?: Record<string, string>;
}
/**
 * @public
 */
export interface StopEarthObservationJobInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the Earth Observation job being stopped.</p>
     */
    Arn: string | undefined;
}
/**
 * @public
 */
export interface StopEarthObservationJobOutput {
}
/**
 * @public
 * <p>The Amazon S3 data for the Vector Enrichment job.</p>
 */
export interface VectorEnrichmentJobS3Data {
    /**
     * @public
     * <p>The URL to the Amazon S3 data for the Vector Enrichment job.</p>
     */
    S3Uri: string | undefined;
    /**
     * @public
     * <p>The Key Management Service key ID for server-side encryption.</p>
     */
    KmsKeyId?: string;
}
/**
 * @public
 * <p>An object containing information about the output file.</p>
 */
export interface ExportVectorEnrichmentJobOutputConfig {
    /**
     * @public
     * <p>The input structure for Amazon S3 data; representing the Amazon S3 location of the input data objects.</p>
     */
    S3Data: VectorEnrichmentJobS3Data | undefined;
}
/**
 * @public
 */
export interface ExportVectorEnrichmentJobInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the Vector Enrichment job.</p>
     */
    Arn: string | undefined;
    /**
     * @public
     * <p>A unique token that guarantees that the call to this API is idempotent.</p>
     */
    ClientToken?: string;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the IAM rolewith permission to upload to the location in OutputConfig.</p>
     */
    ExecutionRoleArn: string | undefined;
    /**
     * @public
     * <p>Output location information for exporting Vector Enrichment Job results.
     * </p>
     */
    OutputConfig: ExportVectorEnrichmentJobOutputConfig | undefined;
}
/**
 * @public
 * @enum
 */
export declare const VectorEnrichmentJobExportStatus: {
    readonly FAILED: "FAILED";
    readonly IN_PROGRESS: "IN_PROGRESS";
    readonly SUCCEEDED: "SUCCEEDED";
};
/**
 * @public
 */
export type VectorEnrichmentJobExportStatus = (typeof VectorEnrichmentJobExportStatus)[keyof typeof VectorEnrichmentJobExportStatus];
/**
 * @public
 */
export interface ExportVectorEnrichmentJobOutput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the Vector Enrichment job being exported.</p>
     */
    Arn: string | undefined;
    /**
     * @public
     * <p>The creation time.</p>
     */
    CreationTime: Date | undefined;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the IAM role with permission to upload to the location in OutputConfig.</p>
     */
    ExecutionRoleArn: string | undefined;
    /**
     * @public
     * <p>The status of the results the Vector Enrichment job being exported.</p>
     */
    ExportStatus: VectorEnrichmentJobExportStatus | undefined;
    /**
     * @public
     * <p>Output location information for exporting Vector Enrichment Job results.
     * </p>
     */
    OutputConfig: ExportVectorEnrichmentJobOutputConfig | undefined;
}
/**
 * @public
 * <p>The structure representing a Geometry in
 *       terms of Type and Coordinates as per GeoJson spec.</p>
 */
export interface Geometry {
    /**
     * @public
     * <p>GeoJson Geometry types like Polygon and MultiPolygon.</p>
     */
    Type: string | undefined;
    /**
     * @public
     * <p>The coordinates of the GeoJson Geometry.</p>
     */
    Coordinates: number[][][] | undefined;
}
/**
 * @public
 */
export interface GetRasterDataCollectionInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the raster data collection.</p>
     */
    Arn: string | undefined;
}
/**
 * @public
 */
export interface GetRasterDataCollectionOutput {
    /**
     * @public
     * <p>The name of the raster data collection.</p>
     */
    Name: string | undefined;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the raster data collection.</p>
     */
    Arn: string | undefined;
    /**
     * @public
     * <p>The raster data collection type.</p>
     */
    Type: DataCollectionType | undefined;
    /**
     * @public
     * <p>A description of the raster data collection.</p>
     */
    Description: string | undefined;
    /**
     * @public
     * <p>The URL of the description page.</p>
     */
    DescriptionPageUrl: string | undefined;
    /**
     * @public
     * <p>The filters supported by the raster data collection.</p>
     */
    SupportedFilters: Filter[] | undefined;
    /**
     * @public
     * <p>The list of image source bands in the raster data collection.</p>
     */
    ImageSourceBands: string[] | undefined;
    /**
     * @public
     * <p>Each tag consists of a key and a value.</p>
     */
    Tags?: Record<string, string>;
}
/**
 * @public
 */
export interface GetVectorEnrichmentJobInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the Vector Enrichment job.</p>
     */
    Arn: string | undefined;
}
/**
 * @public
 * @enum
 */
export declare const VectorEnrichmentJobErrorType: {
    /**
     * CLIENT_ERROR
     */
    readonly CLIENT_ERROR: "CLIENT_ERROR";
    /**
     * SERVER_ERROR
     */
    readonly SERVER_ERROR: "SERVER_ERROR";
};
/**
 * @public
 */
export type VectorEnrichmentJobErrorType = (typeof VectorEnrichmentJobErrorType)[keyof typeof VectorEnrichmentJobErrorType];
/**
 * @public
 * <p>VectorEnrichmentJob error details in response from GetVectorEnrichmentJob.</p>
 */
export interface VectorEnrichmentJobErrorDetails {
    /**
     * @public
     * <p>The type of error generated during the Vector Enrichment job.</p>
     */
    ErrorType?: VectorEnrichmentJobErrorType;
    /**
     * @public
     * <p>A message that you define and then is processed and rendered by
     *          the Vector Enrichment job when the error occurs.</p>
     */
    ErrorMessage?: string;
}
/**
 * @public
 * @enum
 */
export declare const VectorEnrichmentJobExportErrorType: {
    readonly CLIENT_ERROR: "CLIENT_ERROR";
    readonly SERVER_ERROR: "SERVER_ERROR";
};
/**
 * @public
 */
export type VectorEnrichmentJobExportErrorType = (typeof VectorEnrichmentJobExportErrorType)[keyof typeof VectorEnrichmentJobExportErrorType];
/**
 * @public
 * <p>VectorEnrichmentJob export error details in response from GetVectorEnrichmentJob.</p>
 */
export interface VectorEnrichmentJobExportErrorDetails {
    /**
     * @public
     * <p>The output error details for an Export operation on a Vector Enrichment job.</p>
     */
    Type?: VectorEnrichmentJobExportErrorType;
    /**
     * @public
     * <p>The message providing details about the errors generated during the Vector Enrichment job.</p>
     */
    Message?: string;
}
/**
 * @public
 * <p>The input structure for the data source that represents the storage type of the input data objects.</p>
 */
export type VectorEnrichmentJobDataSourceConfigInput = VectorEnrichmentJobDataSourceConfigInput.S3DataMember | VectorEnrichmentJobDataSourceConfigInput.$UnknownMember;
/**
 * @public
 */
export declare namespace VectorEnrichmentJobDataSourceConfigInput {
    /**
     * @public
     * <p>The input structure for the Amazon S3 data that represents the Amazon S3 location of the input data objects.</p>
     */
    interface S3DataMember {
        S3Data: VectorEnrichmentJobS3Data;
        $unknown?: never;
    }
    /**
     * @public
     */
    interface $UnknownMember {
        S3Data?: never;
        $unknown: [string, any];
    }
    interface Visitor<T> {
        S3Data: (value: VectorEnrichmentJobS3Data) => T;
        _: (name: string, value: any) => T;
    }
    const visit: <T>(value: VectorEnrichmentJobDataSourceConfigInput, visitor: Visitor<T>) => T;
}
/**
 * @public
 * @enum
 */
export declare const VectorEnrichmentJobDocumentType: {
    readonly CSV: "CSV";
};
/**
 * @public
 */
export type VectorEnrichmentJobDocumentType = (typeof VectorEnrichmentJobDocumentType)[keyof typeof VectorEnrichmentJobDocumentType];
/**
 * @public
 * <p>The input structure for the InputConfig in a VectorEnrichmentJob.</p>
 */
export interface VectorEnrichmentJobInputConfig {
    /**
     * @public
     * <p>The input structure that defines the data source file type.</p>
     */
    DocumentType: VectorEnrichmentJobDocumentType | undefined;
    /**
     * @public
     * <p>The input structure for the data source that represents the storage type of the input data objects.</p>
     */
    DataSourceConfig: VectorEnrichmentJobDataSourceConfigInput | undefined;
}
/**
 * @public
 * <p>The input structure for Map Matching operation type.</p>
 */
export interface MapMatchingConfig {
    /**
     * @public
     * <p>The field name for the data that describes the identifier representing a collection of GPS points belonging to an individual trace.</p>
     */
    IdAttributeName: string | undefined;
    /**
     * @public
     * <p>The name of the Y-attribute</p>
     */
    YAttributeName: string | undefined;
    /**
     * @public
     * <p>The name of the X-attribute</p>
     */
    XAttributeName: string | undefined;
    /**
     * @public
     * <p>The name of the timestamp attribute.</p>
     */
    TimestampAttributeName: string | undefined;
}
/**
 * @public
 * <p>The input structure for Reverse Geocoding operation type.</p>
 */
export interface ReverseGeocodingConfig {
    /**
     * @public
     * <p>The field name for the data that describes y-axis coordinate, eg. latitude of a point.</p>
     */
    YAttributeName: string | undefined;
    /**
     * @public
     * <p>The field name for the data that describes x-axis coordinate, eg. longitude of a point.</p>
     */
    XAttributeName: string | undefined;
}
/**
 * @public
 * <p>It contains configs such as ReverseGeocodingConfig and MapMatchingConfig.</p>
 */
export type VectorEnrichmentJobConfig = VectorEnrichmentJobConfig.MapMatchingConfigMember | VectorEnrichmentJobConfig.ReverseGeocodingConfigMember | VectorEnrichmentJobConfig.$UnknownMember;
/**
 * @public
 */
export declare namespace VectorEnrichmentJobConfig {
    /**
     * @public
     * <p>The input structure for Reverse Geocoding operation type.</p>
     */
    interface ReverseGeocodingConfigMember {
        ReverseGeocodingConfig: ReverseGeocodingConfig;
        MapMatchingConfig?: never;
        $unknown?: never;
    }
    /**
     * @public
     * <p>The input structure for Map Matching operation type.</p>
     */
    interface MapMatchingConfigMember {
        ReverseGeocodingConfig?: never;
        MapMatchingConfig: MapMatchingConfig;
        $unknown?: never;
    }
    /**
     * @public
     */
    interface $UnknownMember {
        ReverseGeocodingConfig?: never;
        MapMatchingConfig?: never;
        $unknown: [string, any];
    }
    interface Visitor<T> {
        ReverseGeocodingConfig: (value: ReverseGeocodingConfig) => T;
        MapMatchingConfig: (value: MapMatchingConfig) => T;
        _: (name: string, value: any) => T;
    }
    const visit: <T>(value: VectorEnrichmentJobConfig, visitor: Visitor<T>) => T;
}
/**
 * @public
 * @enum
 */
export declare const VectorEnrichmentJobStatus: {
    readonly COMPLETED: "COMPLETED";
    readonly DELETED: "DELETED";
    readonly DELETING: "DELETING";
    readonly FAILED: "FAILED";
    readonly INITIALIZING: "INITIALIZING";
    readonly IN_PROGRESS: "IN_PROGRESS";
    readonly STOPPED: "STOPPED";
    readonly STOPPING: "STOPPING";
};
/**
 * @public
 */
export type VectorEnrichmentJobStatus = (typeof VectorEnrichmentJobStatus)[keyof typeof VectorEnrichmentJobStatus];
/**
 * @public
 * @enum
 */
export declare const VectorEnrichmentJobType: {
    readonly MAP_MATCHING: "MAP_MATCHING";
    readonly REVERSE_GEOCODING: "REVERSE_GEOCODING";
};
/**
 * @public
 */
export type VectorEnrichmentJobType = (typeof VectorEnrichmentJobType)[keyof typeof VectorEnrichmentJobType];
/**
 * @public
 */
export interface GetVectorEnrichmentJobOutput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the Vector Enrichment job.</p>
     */
    Arn: string | undefined;
    /**
     * @public
     * <p>The type of the Vector Enrichment job being initiated.</p>
     */
    Type: VectorEnrichmentJobType | undefined;
    /**
     * @public
     * <p>The name of the Vector Enrichment job.</p>
     */
    Name: string | undefined;
    /**
     * @public
     * <p>The creation time.</p>
     */
    CreationTime: Date | undefined;
    /**
     * @public
     * <p>The duration of the Vector Enrichment job, in seconds.</p>
     */
    DurationInSeconds: number | undefined;
    /**
     * @public
     * <p>The status of the initiated Vector Enrichment job.</p>
     */
    Status: VectorEnrichmentJobStatus | undefined;
    /**
     * @public
     * <p>The Key Management Service key ID for server-side encryption.</p>
     */
    KmsKeyId?: string;
    /**
     * @public
     * <p>Input configuration information for the Vector Enrichment job.</p>
     */
    InputConfig: VectorEnrichmentJobInputConfig | undefined;
    /**
     * @public
     * <p>An object containing information about the job configuration.</p>
     */
    JobConfig: VectorEnrichmentJobConfig | undefined;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the IAM role that you specified for the job.</p>
     */
    ExecutionRoleArn: string | undefined;
    /**
     * @public
     * <p>Details about the errors generated during the Vector Enrichment job.</p>
     */
    ErrorDetails?: VectorEnrichmentJobErrorDetails;
    /**
     * @public
     * <p>The export status of the Vector Enrichment job being initiated.</p>
     */
    ExportStatus?: VectorEnrichmentJobExportStatus;
    /**
     * @public
     * <p>Details about the errors generated during the ExportVectorEnrichmentJob.</p>
     */
    ExportErrorDetails?: VectorEnrichmentJobExportErrorDetails;
    /**
     * @public
     * <p>Each tag consists of a key and a value.</p>
     */
    Tags?: Record<string, string>;
}
/**
 * @public
 * <p>Properties associated with the Item.</p>
 */
export interface Properties {
    /**
     * @public
     * <p>Estimate of cloud cover.</p>
     */
    EoCloudCover?: number;
    /**
     * @public
     * <p>The angle from the sensor between nadir (straight down) and the scene center. Measured in degrees (0-90).</p>
     */
    ViewOffNadir?: number;
    /**
     * @public
     * <p>The sun azimuth angle. From the scene center point on the ground, this is the angle between truth north and the sun.
     *       Measured clockwise in degrees (0-360).</p>
     */
    ViewSunAzimuth?: number;
    /**
     * @public
     * <p>The sun elevation angle. The angle from the tangent of the scene center point to the sun. Measured from the horizon in degrees (-90-90).
     *       Negative values indicate the sun is below the horizon, e.g. sun elevation of -10° means the data was captured during <a href="https://www.timeanddate.com/astronomy/different-types-twilight.html">nautical twilight</a>.</p>
     */
    ViewSunElevation?: number;
    /**
     * @public
     * <p>Platform property. Platform refers to the unique name
     *       of the specific platform the instrument is attached to.
     *       For satellites it is the name of
     *       the satellite, eg. landsat-8 (Landsat-8), sentinel-2a.</p>
     */
    Platform?: string;
    /**
     * @public
     * <p>Land cloud cover for Landsat Data Collection.</p>
     */
    LandsatCloudCoverLand?: number;
}
/**
 * @public
 * <p>The structure representing the items in the response for SearchRasterDataCollection.</p>
 */
export interface ItemSource {
    /**
     * @public
     * <p>A unique Id for the source item.</p>
     */
    Id: string | undefined;
    /**
     * @public
     * <p>The item Geometry in GeoJson format.</p>
     */
    Geometry: Geometry | undefined;
    /**
     * @public
     * <p>This is a dictionary of Asset Objects data associated with the Item that
     *       can be downloaded or streamed, each with a unique key.</p>
     */
    Assets?: Record<string, AssetValue>;
    /**
     * @public
     * <p>The searchable date and time of the item, in UTC.</p>
     */
    DateTime: Date | undefined;
    /**
     * @public
     * <p>This field contains additional properties of the item.</p>
     */
    Properties?: Properties;
}
/**
 * @public
 */
export interface ListRasterDataCollectionsInput {
    /**
     * @public
     * <p>If the previous response was truncated, you receive this token.
     *          Use it in your next request to receive the next set of results.</p>
     */
    NextToken?: string;
    /**
     * @public
     * <p>The total number of items to return.</p>
     */
    MaxResults?: number;
}
/**
 * @public
 */
export interface ListRasterDataCollectionsOutput {
    /**
     * @public
     * <p>Contains summary information about the raster data collection.</p>
     */
    RasterDataCollectionSummaries: RasterDataCollectionMetadata[] | undefined;
    /**
     * @public
     * <p>If the previous response was truncated, you receive this token.
     *          Use it in your next request to receive the next set of results.</p>
     */
    NextToken?: string;
}
/**
 * @public
 */
export interface ListTagsForResourceRequest {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the resource you want to tag.</p>
     */
    ResourceArn: string | undefined;
}
/**
 * @public
 */
export interface ListTagsForResourceResponse {
    /**
     * @public
     * <p>Each tag consists of a key and a value.</p>
     */
    Tags?: Record<string, string>;
}
/**
 * @public
 */
export interface ListVectorEnrichmentJobInput {
    /**
     * @public
     * <p>A filter that retrieves only jobs with a specific status.</p>
     */
    StatusEquals?: string;
    /**
     * @public
     * <p>An optional value that specifies whether you want the results sorted in <code>Ascending</code> or <code>Descending</code> order.</p>
     */
    SortOrder?: SortOrder;
    /**
     * @public
     * <p>The parameter by which to sort the results.</p>
     */
    SortBy?: string;
    /**
     * @public
     * <p>If the previous response was truncated, you receive this token.
     *          Use it in your next request to receive the next set of results.</p>
     */
    NextToken?: string;
    /**
     * @public
     * <p>The maximum number of items to return.</p>
     */
    MaxResults?: number;
}
/**
 * @public
 * <p>An object containing information about the output file.</p>
 */
export interface ListVectorEnrichmentJobOutputConfig {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the list of the Vector Enrichment jobs.</p>
     */
    Arn: string | undefined;
    /**
     * @public
     * <p>The names of the Vector Enrichment jobs in the list.</p>
     */
    Name: string | undefined;
    /**
     * @public
     * <p>The type of the list of Vector Enrichment jobs.</p>
     */
    Type: VectorEnrichmentJobType | undefined;
    /**
     * @public
     * <p>The creation time.</p>
     */
    CreationTime: Date | undefined;
    /**
     * @public
     * <p>The duration of the session, in seconds.</p>
     */
    DurationInSeconds: number | undefined;
    /**
     * @public
     * <p>The status of the Vector Enrichment jobs list. </p>
     */
    Status: VectorEnrichmentJobStatus | undefined;
    /**
     * @public
     * <p>Each tag consists of a key and a value.</p>
     */
    Tags?: Record<string, string>;
}
/**
 * @public
 */
export interface ListVectorEnrichmentJobOutput {
    /**
     * @public
     * <p>Contains summary information about the Vector Enrichment jobs.</p>
     */
    VectorEnrichmentJobSummaries: ListVectorEnrichmentJobOutputConfig[] | undefined;
    /**
     * @public
     * <p>If the previous response was truncated, you receive this token.
     *          Use it in your next request to receive the next set of results.</p>
     */
    NextToken?: string;
}
/**
 * @public
 * <p>This is a RasterDataCollectionQueryInput containing AreaOfInterest, Time Range filter and Property filters.</p>
 */
export interface RasterDataCollectionQueryWithBandFilterInput {
    /**
     * @public
     * <p>The TimeRange Filter used in the search query.</p>
     */
    TimeRangeFilter: TimeRangeFilterInput | undefined;
    /**
     * @public
     * <p>The Area of interest to be used in the search query.</p>
     */
    AreaOfInterest?: AreaOfInterest;
    /**
     * @public
     * <p>The Property Filters used in the search query.</p>
     */
    PropertyFilters?: PropertyFilters;
    /**
     * @public
     * <p>The list of Bands to be displayed in the result for each item.</p>
     */
    BandFilter?: string[];
}
/**
 * @public
 */
export interface SearchRasterDataCollectionInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the raster data collection.</p>
     */
    Arn: string | undefined;
    /**
     * @public
     * <p>RasterDataCollectionQuery consisting of <a href="https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_geospatial_AreaOfInterest.html">AreaOfInterest(AOI)</a>, <a href="https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_geospatial_PropertyFilter.html">PropertyFilters</a> and
     *       <a href="https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_geospatial_TimeRangeFilterInput.html">TimeRangeFilterInput</a> used in <a href="https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_geospatial_SearchRasterDataCollection.html">SearchRasterDataCollection</a>.</p>
     */
    RasterDataCollectionQuery: RasterDataCollectionQueryWithBandFilterInput | undefined;
    /**
     * @public
     * <p>If the previous response was truncated, you receive this token.
     *          Use it in your next request to receive the next set of results.</p>
     */
    NextToken?: string;
}
/**
 * @public
 */
export interface SearchRasterDataCollectionOutput {
    /**
     * @public
     * <p>Approximate number of results in the response.</p>
     */
    ApproximateResultCount: number | undefined;
    /**
     * @public
     * <p>If the previous response was truncated, you receive this token.
     *          Use it in your next request to receive the next set of results.</p>
     */
    NextToken?: string;
    /**
     * @public
     * <p>List of items matching the Raster DataCollectionQuery.</p>
     */
    Items?: ItemSource[];
}
/**
 * @public
 */
export interface TagResourceRequest {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the resource you want to tag.</p>
     */
    ResourceArn: string | undefined;
    /**
     * @public
     * <p>Each tag consists of a key and a value.</p>
     */
    Tags: Record<string, string> | undefined;
}
/**
 * @public
 */
export interface TagResourceResponse {
}
/**
 * @public
 */
export interface UntagResourceRequest {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the resource you want to untag.</p>
     */
    ResourceArn: string | undefined;
    /**
     * @public
     * <p>Keys of the tags you want to remove.</p>
     */
    TagKeys: string[] | undefined;
}
/**
 * @public
 */
export interface UntagResourceResponse {
}
/**
 * @public
 */
export interface StartVectorEnrichmentJobInput {
    /**
     * @public
     * <p>The name of the Vector Enrichment job.</p>
     */
    Name: string | undefined;
    /**
     * @public
     * <p>A unique token that guarantees that the call to this API is idempotent.</p>
     */
    ClientToken?: string;
    /**
     * @public
     * <p>The Key Management Service key ID for server-side encryption.</p>
     */
    KmsKeyId?: string;
    /**
     * @public
     * <p>Input configuration information for the Vector Enrichment job.</p>
     */
    InputConfig: VectorEnrichmentJobInputConfig | undefined;
    /**
     * @public
     * <p>An object containing information about the job configuration.</p>
     */
    JobConfig: VectorEnrichmentJobConfig | undefined;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the IAM role that you specified for the job.</p>
     */
    ExecutionRoleArn: string | undefined;
    /**
     * @public
     * <p>Each tag consists of a key and a value.</p>
     */
    Tags?: Record<string, string>;
}
/**
 * @public
 */
export interface StartVectorEnrichmentJobOutput {
    /**
     * @public
     * <p>The name of the Vector Enrichment job.</p>
     */
    Name: string | undefined;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the Vector Enrichment job.</p>
     */
    Arn: string | undefined;
    /**
     * @public
     * <p>The type of the Vector Enrichment job.</p>
     */
    Type: VectorEnrichmentJobType | undefined;
    /**
     * @public
     * <p>The creation time.</p>
     */
    CreationTime: Date | undefined;
    /**
     * @public
     * <p>The duration of the Vector Enrichment job, in seconds.</p>
     */
    DurationInSeconds: number | undefined;
    /**
     * @public
     * <p>The status of the Vector Enrichment job being started.</p>
     */
    Status: VectorEnrichmentJobStatus | undefined;
    /**
     * @public
     * <p>The Key Management Service key ID for server-side encryption.</p>
     */
    KmsKeyId?: string;
    /**
     * @public
     * <p>Input configuration information for starting the Vector Enrichment job.</p>
     */
    InputConfig: VectorEnrichmentJobInputConfig | undefined;
    /**
     * @public
     * <p>An object containing information about the job configuration.</p>
     */
    JobConfig: VectorEnrichmentJobConfig | undefined;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the IAM role that you specified for the job.</p>
     */
    ExecutionRoleArn: string | undefined;
    /**
     * @public
     * <p>Each tag consists of a key and a value.</p>
     */
    Tags?: Record<string, string>;
}
/**
 * @public
 */
export interface StopVectorEnrichmentJobInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the Vector Enrichment job.</p>
     */
    Arn: string | undefined;
}
/**
 * @public
 */
export interface StopVectorEnrichmentJobOutput {
}
/**
 * @internal
 */
export declare const MultiPolygonGeometryInputFilterSensitiveLog: (obj: MultiPolygonGeometryInput) => any;
/**
 * @internal
 */
export declare const PolygonGeometryInputFilterSensitiveLog: (obj: PolygonGeometryInput) => any;
/**
 * @internal
 */
export declare const AreaOfInterestGeometryFilterSensitiveLog: (obj: AreaOfInterestGeometry) => any;
/**
 * @internal
 */
export declare const AreaOfInterestFilterSensitiveLog: (obj: AreaOfInterest) => any;
/**
 * @internal
 */
export declare const TimeRangeFilterOutputFilterSensitiveLog: (obj: TimeRangeFilterOutput) => any;
/**
 * @internal
 */
export declare const RasterDataCollectionQueryOutputFilterSensitiveLog: (obj: RasterDataCollectionQueryOutput) => any;
/**
 * @internal
 */
export declare const InputConfigOutputFilterSensitiveLog: (obj: InputConfigOutput) => any;
/**
 * @internal
 */
export declare const GetEarthObservationJobOutputFilterSensitiveLog: (obj: GetEarthObservationJobOutput) => any;
/**
 * @internal
 */
export declare const GetTileOutputFilterSensitiveLog: (obj: GetTileOutput) => any;
/**
 * @internal
 */
export declare const ListEarthObservationJobInputFilterSensitiveLog: (obj: ListEarthObservationJobInput) => any;
/**
 * @internal
 */
export declare const ListEarthObservationJobOutputFilterSensitiveLog: (obj: ListEarthObservationJobOutput) => any;
/**
 * @internal
 */
export declare const TimeRangeFilterInputFilterSensitiveLog: (obj: TimeRangeFilterInput) => any;
/**
 * @internal
 */
export declare const RasterDataCollectionQueryInputFilterSensitiveLog: (obj: RasterDataCollectionQueryInput) => any;
/**
 * @internal
 */
export declare const InputConfigInputFilterSensitiveLog: (obj: InputConfigInput) => any;
/**
 * @internal
 */
export declare const StartEarthObservationJobInputFilterSensitiveLog: (obj: StartEarthObservationJobInput) => any;
/**
 * @internal
 */
export declare const StartEarthObservationJobOutputFilterSensitiveLog: (obj: StartEarthObservationJobOutput) => any;
/**
 * @internal
 */
export declare const GeometryFilterSensitiveLog: (obj: Geometry) => any;
/**
 * @internal
 */
export declare const ItemSourceFilterSensitiveLog: (obj: ItemSource) => any;
/**
 * @internal
 */
export declare const ListRasterDataCollectionsInputFilterSensitiveLog: (obj: ListRasterDataCollectionsInput) => any;
/**
 * @internal
 */
export declare const ListRasterDataCollectionsOutputFilterSensitiveLog: (obj: ListRasterDataCollectionsOutput) => any;
/**
 * @internal
 */
export declare const ListVectorEnrichmentJobInputFilterSensitiveLog: (obj: ListVectorEnrichmentJobInput) => any;
/**
 * @internal
 */
export declare const ListVectorEnrichmentJobOutputFilterSensitiveLog: (obj: ListVectorEnrichmentJobOutput) => any;
/**
 * @internal
 */
export declare const RasterDataCollectionQueryWithBandFilterInputFilterSensitiveLog: (obj: RasterDataCollectionQueryWithBandFilterInput) => any;
/**
 * @internal
 */
export declare const SearchRasterDataCollectionInputFilterSensitiveLog: (obj: SearchRasterDataCollectionInput) => any;
/**
 * @internal
 */
export declare const SearchRasterDataCollectionOutputFilterSensitiveLog: (obj: SearchRasterDataCollectionOutput) => any;
